@@ -65,6 +65,7 @@ class QuenchPlanAnalysis():
 
         self.MergedVoltages = {}
         self.MergedVoltagesPolarities = {}
+        self.CopyMVP = []
 
         self.SIMdata = SIMdata()
         self.SIMdata.FileName = FileNameSIMData
@@ -362,8 +363,9 @@ class QuenchPlanAnalysis():
             ax.set_xlabel("x [mm]")
             ax.set_ylabel("y [mm]")
             ax.set_title("Turns to V-Taps")
-            # ax.legend(legend)
-            ax.legend(legend, loc='upper right')
+            ax.legend(legend, loc='best', bbox_to_anchor=(1.05, 1.0))
+            plt.tight_layout()
+
         return
 
     def GetTDMSCoilStructure(self):
@@ -494,8 +496,9 @@ class QuenchPlanAnalysis():
 
     def __CreateVoltageVertices(self):
         ## 1. Extract all channels that are relevant
-        temp_Sections = re.compile("([a-zA-Z]+)([0-9]+)([a-zA-Z]+)([0-9]+)([a-zA-Z]+)([0-9]+)")
-        temp_Coils = re.compile("([0-9]+)([a-zA-Z]+)")
+        # Version 1
+        temp_Sections_1 = re.compile("([a-zA-Z]+)([0-9]+)([a-zA-Z]+)([0-9]+)([a-zA-Z]+)([0-9]+)")
+        temp_Coils_1 = re.compile("([0-9]+)([a-zA-Z]+)")
         CSections = []
         Coils = []
         Coils_Diff = []
@@ -506,14 +509,23 @@ class QuenchPlanAnalysis():
                 chName = chName.replace("-"," ")
                 chName = chName.replace(" ", "")
                 try:
-                    res = temp_Sections.match(chName).groups()
+                    res = temp_Sections_1.match(chName).groups()
                     ChN = res + (str(res[0]+res[1]+'_'+res[2]+res[3]+"_"+res[4]+res[5]),) + (str(res[0]+res[1]+'_'+res[4]+res[5]+"_"+res[2]+res[3]),)+ (channel.name,)
                     CSections.append(ChN)
                 except:
-                    pass
+                    chName = channel.name.replace("_", "I")
+                    chName = chName.replace("-", "O")
+                    chName = chName.replace(" ", "")
+                    try:
+                        res = temp_Sections_1.match(chName).groups()
+                        ChN = res + (str(res[0] + res[1] + '_'  + res[3] + "_" + res[5]),) + (
+                        str(res[0] + res[1] + '_' + res[5] + "_"  + res[3]),) + (channel.name,)
+                        CSections.append(ChN)
+                    except:
+                        pass
                 if chName.startswith("Vcoil"):
                     try:
-                        res = temp_Coils.match(chName[5:]).groups()
+                        res = temp_Coils_1.match(chName[5:]).groups()
                         ChN = res + (channel.name,)
                         Coils_Diff.append(ChN)
                     except:
@@ -540,6 +552,7 @@ class QuenchPlanAnalysis():
                 for i in range(len(Coil)):
                     self.MergedVoltages = {**self.MergedVoltages, **Coil[i]}
                 MVcopy = self.MergedVoltages.copy()
+                counter = 0
                 for old_key in MVcopy.keys():
                     if len(self.MergedVoltages[old_key]) == 0:
                         self.MergedVoltages.pop(old_key)
@@ -549,17 +562,20 @@ class QuenchPlanAnalysis():
                             if old_key == self.TDMSdata.VoltageVertices[i][6] or  old_key == self.TDMSdata.VoltageVertices[i][7]:
                                 new_key = self.TDMSdata.VoltageVertices[i][8]
                                 self.MergedVoltages[new_key] = self.MergedVoltages.pop(old_key)
-                                if int(self.TDMSdata.VoltageVertices[i][3]) > int(self.TDMSdata.VoltageVertices[i][5]):
-                                    if self.TDMSdata.VoltageVertices[i][2] == 'I' and self.TDMSdata.VoltageVertices[i][4] == 'O':
-                                        self.MergedVoltagesPolarities[new_key] = 1
-                                    else: self.MergedVoltagesPolarities[new_key] = -1
-                                else:
-                                    self.MergedVoltagesPolarities[new_key] = 1
+                                # if int(self.TDMSdata.VoltageVertices[i][3]) > int(self.TDMSdata.VoltageVertices[i][5]):
+                                #     if self.TDMSdata.VoltageVertices[i][2] == 'I' and self.TDMSdata.VoltageVertices[i][4] == 'O':
+                                #         self.MergedVoltagesPolarities[new_key] = 1
+                                #     else: self.MergedVoltagesPolarities[new_key] = -1
+                                # else:
+                                #     self.MergedVoltagesPolarities[new_key] = 1
+                                self.MergedVoltagesPolarities[new_key] = self.CopyMVP[counter]
+                                counter = counter + 1
                                 found = 1
                                 break
                         if not found:
                             if self.verbose: print("Couldn't find voltage-tap: {} in TDMS.".format(old_key))
                             self.MergedVoltages.pop(old_key)
+                            counter = counter + 1
                 return
             else:
                 self.__CreateTDMSDataObject()
@@ -575,6 +591,7 @@ class QuenchPlanAnalysis():
                 Coil = []
                 for row in csv_reader:
                     if not any(row): continue
+                    if not row[0]: continue
                     if counter<2:
                         counter = counter +1
                         continue
@@ -583,12 +600,17 @@ class QuenchPlanAnalysis():
                         if current_dict: Coil.append(current_dict)
                         current_dict = {}
                         c_coil = current_coil
-                    key_name = 'C'+row[0]+'_'+row[1]+'_'+row[2]
+
+                    if float(row[0])<100:
+                        key_name = 'P' + row[0] + '_' + row[1] + '-' + row[2]
+                    else:
+                        key_name = 'C'+row[0]+'_'+row[1]+'_'+row[2]
                     nTurns = float(row[3])
                     if nTurns == 0: continue
                     turns = self.SIMdata.el_connections[turn_count:turn_count+int(nTurns*2)]
                     current_dict[key_name] = turns[:,0]
                     turn_count = turn_count + int(nTurns*2)
+                    self.CopyMVP.append(float(row[4]))
                 Coil.append(current_dict)
             self.ProvideTurnsToCoilStructure(Coil)
             return
