@@ -226,7 +226,7 @@ def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim, verbose = False):
     a = QuenchPlanAnalysis(FileName_TDMS, FileName_Sim, verbose = verbose)
     # a = QuenchPlanAnalysis(0, FileName_Sim)
     # a.ProvideTurnsToCoilStructure(Coil = [Coil109,Coil110,Coil111,Coil108])
-    a.ProvideTurnsToCoilStructure(CoilCsv = 'C:\cernbox\MasterThesis\CoilStructure_MQXFS4b.csv')
+    a.ProvideTurnsToCoilStructure(CoilCsv = 'C:\cernbox\MasterThesis\CoilStructure_MQXFPB2.csv')
     # a.QuenchPlanAnalysis(Plot = 1)
     # a.FindQuenchTDMS(0.1, 0.007, Plot=0)
     a.PlotVoltageTap(Coil = 110)
